@@ -1,9 +1,6 @@
-from datetime import datetime
-
-
 from .client import Client
 from .converter import Converter
-from .exceptions import NotChecked
+
 
 class ArfToHtml(Client):
     def __init__(self, args):
@@ -11,6 +8,9 @@ class ArfToHtml(Client):
         self.off_webbrowser = self.arg.off_web_browser
         self.show_failed_rules = self.arg.show_failed_rules
         self.show_not_selected_rules = self.arg.show_not_selected_rules
+        self.all_in_one = self.arg.all_in_one
+        if self.all_in_one:
+            self.all_rules = True
 
     def _get_message(self):
         MESSAGES = {
@@ -24,20 +24,19 @@ class ArfToHtml(Client):
         converter = Converter(self.xml_parser.get_oval_tree(rule_id))
         return converter.to_JsTree_dict(self.hide_passing_tests)
 
-    def prepare_data(self, rules):
-        out = []
-        for rule in rules['rules']:
-            try:
-                oval_tree_dict = self.create_dict_of_rule(rule)
-                src = self.get_save_src(rule)
-                self.save_html_and_open_html(
-                    oval_tree_dict, src, rule, out)
-            except NotChecked as error:
-                self.print_red_text(error)
-        return out
+    def _put_to_dict_oval_trees(self, dict_oval_trees, rule):
+        dict_oval_trees[rule] = self.create_dict_of_rule(rule)
+
+    def _get_src_for_one_graph(self, rule):
+        return self.get_save_src(rule + self.date)
 
     def prepare_parser(self):
         super().prepare_parser()
+        self.parser.add_argument(
+            '--all-in-one',
+            action="store_true",
+            default=False,
+            help="Processes all rules into one file.")
         self.parser.add_argument(
             '--off-web-browser',
             action="store_true",
