@@ -9,6 +9,8 @@ from datetime import datetime
 import sys
 
 from .xml_parser import XmlParser
+from .exceptions import NotChecked
+from ._builder_html_graph import BuilderHtmlGraph
 
 
 class Client():
@@ -21,12 +23,16 @@ class Client():
         self.rule_name = self.arg.rule_id
         self.out = self.arg.output
         self.all_rules = self.arg.all
+        self.all_in_one = None
+        self.off_webbrowser = None
         self.isatty = sys.stdout.isatty()
         self.show_failed_rules = False
         self.show_not_selected_rules = False
         self.xml_parser = XmlParser(
             self.source_filename)
         self.parts = self.get_src('parts')
+        self.START_OF_FILE_NAME = 'graph-of-'
+        self.date = str(datetime.now().strftime("-%d_%m_%Y-%H_%M_%S"))
 
     def _get_message(self):
         MESSAGES = {
@@ -44,7 +50,7 @@ class Client():
     def run_gui_and_return_answers(self):
         if self.isatty:
             if self.all_rules:
-                return {'rules': self.search_rules_id()}
+                return self._get_rules()
             else:
                 try:
                     import inquirer
@@ -53,13 +59,17 @@ class Client():
                     print(self.get_selection_rules())
                     return None
         else:
-            return {'rules': self.search_rules_id()}
+            return self._get_rules()
+
+    def _get_rules(self):
+        return {
+            'rules': self._get_only_fail_rule(
+                self.search_rules_id())} if self.show_failed_rules else {
+            'rules': self.search_rules_id()}
 
     def get_list_of_matched_rules(self):
-        rules = self.search_rules_id()
-        if self.show_failed_rules:
-            rules = self._get_only_fail_rule(rules)
-        return rules
+        return self._get_only_fail_rule(
+            self.search_rules_id()) if self.show_failed_rules else self.search_rules_id()
 
     def get_list_of_lines(self):
         lines = ['== The Rule IDs ==']
@@ -85,13 +95,9 @@ class Client():
         return out
 
     def get_choices(self):
-        rules = self.search_rules_id()
-        if self.show_failed_rules:
-            rules = self._get_only_fail_rule(rules)
-        choices = rules
         if self.show_not_selected_rules:
             print("\n".join(self.get_lines_of_wanted_not_selected_rules()))
-        return choices
+        return self.get_list_of_matched_rules()
 
     def get_questions(self):
         choices = self.get_choices()
@@ -119,11 +125,11 @@ class Client():
                 self.rule_name, x)]
 
     def search_rules_id(self):
-        rules = self._get_wanted_rules_from_array_of_IDs(
-            self.xml_parser.used_rules.keys())
-        notselected_rules = self._get_wanted_rules_from_array_of_IDs(
-            self.xml_parser.notselected_rules)
-        return self._check_rules_id(rules, notselected_rules)
+        return self._check_rules_id(
+            self._get_wanted_rules_from_array_of_IDs(
+                self.xml_parser.used_rules.keys()),
+            self._get_wanted_rules_from_array_of_IDs(
+                self.xml_parser.notselected_rules))
 
     def _check_rules_id(self, rules, notselected_rules):
         if len(notselected_rules) and not rules:
@@ -140,56 +146,50 @@ class Client():
         else:
             return rules
 
-    def save_html_and_open_html(self, oval_tree_dict, src, rule, out):
-        self.save_html_report(oval_tree_dict, src)
-        print('Rule "{}" done!'.format(rule))
-        out.append(src)
-        self.open_web_browser(src)
-
-    def open_web_browser(self, src):
-        if not self.off_webbrowser:
-            try:
-                webbrowser.get('firefox').open_new_tab(src)
-            except BaseException:
-                webbrowser.open_new_tab(src)
-
-    def get_src(self, src):
-        _dir = os.path.dirname(os.path.realpath(__file__))
-        FIXTURE_DIR = os.path.join(_dir, src)
-        return str(FIXTURE_DIR)
-
     def get_save_src(self, rule):
-        date = str(datetime.now().strftime("-%d_%m_%Y-%H_%M_%S"))
         if self.out is not None:
             os.makedirs(self.out, exist_ok=True)
             return os.path.join(
                 self.out,
-                'graph-of-' + rule + date + '.html')
+                self.START_OF_FILE_NAME + rule + '.html')
         return os.path.join(
             os.getcwd(),
-            'graph-of-' + rule + date + '.html')
+            self.START_OF_FILE_NAME + rule + '.html')
 
-    def _get_part(self, part):
-        with open(os.path.join(self.parts, part), "r") as data_file:
-            return data_file.readlines()
+    def get_src(self, src):
+        _dir = os.path.dirname(os.path.realpath(__file__))
+        return str(os.path.join(_dir, src))
 
-    def _merge_report_parts(self, data):
-        head = self._get_part('head.html')
-        body = self._get_part('body.html')
-        script = self._get_part('script.js')
-        footer = ['</script>', '</body>', '</html>']
-        return [*head, data, *body, *script, *footer]
+    def _build_and_save_html(self, dict_oval_trees, src, rules, out):
+        builder = BuilderHtmlGraph(self.parts, self.off_webbrowser)
+        builder.save_html_and_open_html(dict_oval_trees, src, rules, out)
 
-    def save_html_report(self, dict_, src):
-        data = "var data_of_tree =" + str(
-            json.dumps(dict_, sort_keys=False, indent=4) + ";")
-        with open(src, "w+") as data_file:
-            data_file.writelines(self._merge_report_parts(data))
+    def _prepare_data(self, rules, dict_oval_trees, out):
+        for rule in rules['rules']:
+            try:
+                self._put_to_dict_oval_trees(dict_oval_trees, rule)
+                if not self.all_in_one:
+                    self._build_and_save_html(
+                        dict_oval_trees, self._get_src_for_one_graph(
+                            rule), dict(
+                            rules=[rule]), out)
+                    dict_oval_trees = {}
+            except NotChecked as error:
+                self.print_red_text(error)
+        if self.all_in_one:
+            self._build_and_save_html(
+                dict_oval_trees, self.get_save_src(
+                    'rules' + self.date), rules, out)
+        return out
+
+    def prepare_data(self, rules):
+        out = []
+        oval_tree_dict = dict()
+        return self._prepare_data(rules, oval_tree_dict, out)
 
     def parse_arguments(self, args):
         self.prepare_parser()
-        args = self.parser.parse_args(args)
-        return args
+        return self.parser.parse_args(args)
 
     def prepare_parser(self):
         self.parser = argparse.ArgumentParser(
