@@ -2,8 +2,8 @@ import webbrowser
 import json
 import os
 import argparse
-import shutil
 from datetime import datetime
+import shutil
 import sys
 import re
 
@@ -12,6 +12,7 @@ from .oval_node import restore_dict_to_tree
 from .converter import Converter
 from .exceptions import NotChecked
 
+
 class JsonToHtml(Client):
     def __init__(self, args):
         self.parser = None
@@ -22,14 +23,17 @@ class JsonToHtml(Client):
         self.source_filename = self.arg.source_filename
         self.rule_name = self.arg.rule_id
         self.out = self.arg.output
-        self.all_rules = self.arg.all
+        self.all_in_one = self.arg.all_in_one
+        self.all_rules = True if self.all_in_one else self.arg.all
         self.isatty = sys.stdout.isatty()
-        self.show_fail_rules = False
+        self.show_failed_rules = False
         self.show_not_selected_rules = False
         self.oval_tree = None
         self.off_webbrowser = self.arg.off_web_browser
         self.json_data_file = self.get_json_data_file()
         self.parts = self.get_src('parts')
+        self.START_OF_FILE_NAME = 'graph-of-'
+        self.date = datetime.now().strftime("-%d_%m_%Y-%H_%M_%S")
 
     def _get_message(self):
         MESSAGES = {
@@ -64,41 +68,30 @@ class JsonToHtml(Client):
     def load_rule_names(self):
         return self.json_data_file.keys()
 
-    def get_rules_id(self):
-        out = []
-        for id_ in self.load_rule_names():
-            out.append(id_)
-        return out
-
-    def get_choices(self):
-        rules = self.search_rules_id()
-        choices = []
-        for rule in rules:
-            choices.append(rule)
-        return choices
-
     def search_rules_id(self):
-        rules = self._get_wanted_rules_from_array_of_IDs(self.get_rules_id())
+        rules = self._get_wanted_rules_from_array_of_IDs(
+            self.load_rule_names())
         notselected_rules = []
         return self._check_rules_id(rules, notselected_rules)
 
-    def prepare_data(self, rules):
-        out = []
-        for rule in rules["rules"]:
-            try:
-                self.oval_tree = self.load_json_to_oval_tree(rule)
-                oval_tree_dict = self.create_dict_of_oval_node(
-                    self.oval_tree)
-                src = self.get_save_src(
-                    rule.replace('graph-of-', '') + "-")
-                self.save_html_and_open_html(
-                    oval_tree_dict, src, rule, out)
-            except NotChecked as error:
-                self.print_red_text(error)
-        return out
+    def create_dict_of_rule(self, rule):
+        self.oval_tree = self.load_json_to_oval_tree(rule)
+        return self.create_dict_of_oval_node(self.oval_tree)
+
+    def _put_to_dict_oval_trees(self, dict_oval_trees, rule):
+        dict_oval_trees[rule.replace(
+            self.START_OF_FILE_NAME, '')] = self.create_dict_of_rule(rule)
+
+    def _get_src_for_one_graph(self, rule):
+        return self.get_save_src(rule.replace(self.START_OF_FILE_NAME, ''))
 
     def prepare_parser(self):
         super().prepare_parser()
+        self.parser.add_argument(
+            '--all-in-one',
+            action="store_true",
+            default=False,
+            help="Processes all rules into one file.")
         self.parser.add_argument(
             '--off-web-browser',
             action="store_true",
